### common config
+{
    'DBI' => {
        connect_info => [ 'DBI:SQLite:dbname=data.db' ],
    }
};
